Class: Google::Apis::VpcaccessV1::Subnet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vpcaccess_v1/classes.rb,
lib/google/apis/vpcaccess_v1/representations.rb,
lib/google/apis/vpcaccess_v1/representations.rb

Overview

The subnet in which to house the connector

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subnet

Returns a new instance of Subnet.



482
483
484
# File 'lib/google/apis/vpcaccess_v1/classes.rb', line 482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Optional. Subnet name (relative, not fully qualified). E.g. if the full subnet selfLink is https://compute.googleapis.com/compute/v1/projects/`project`/ regions/region/subnetworks/subnetName the correct input for this field would be subnetName Corresponds to the JSON property name

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/vpcaccess_v1/classes.rb', line 474

def name
  @name
end

#project_idString

Optional. Project in which the subnet exists. If not set, this project is assumed to be the project for which the connector create request was issued. Corresponds to the JSON property projectId

Returns:

  • (String)


480
481
482
# File 'lib/google/apis/vpcaccess_v1/classes.rb', line 480

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



487
488
489
490
# File 'lib/google/apis/vpcaccess_v1/classes.rb', line 487

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
end