Class: Google::Apis::VpcaccessV1::ServerlessVPCAccessService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::VpcaccessV1::ServerlessVPCAccessService
- Defined in:
- lib/google/apis/vpcaccess_v1/service.rb
Overview
Serverless VPC Access API
API for managing VPC access connectors.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://vpcaccess.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_connector(parent, connector_object = nil, connector_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Operation
Creates a Serverless VPC Access connector, returns an operation.
-
#delete_project_location_connector(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Operation
Deletes a Serverless VPC Access connector.
-
#get_project_location_connector(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Connector
Gets a Serverless VPC Access connector.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ ServerlessVPCAccessService
constructor
A new instance of ServerlessVPCAccessService.
-
#list_project_location_connectors(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::ListConnectorsResponse
Lists Serverless VPC Access connectors.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_connector(name, connector_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Operation
Updates a Serverless VPC Access connector, returns an operation.
Constructor Details
#initialize ⇒ ServerlessVPCAccessService
Returns a new instance of ServerlessVPCAccessService.
47 48 49 50 51 52 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-vpcaccess_v1', client_version: Google::Apis::VpcaccessV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_project_location_connector(parent, connector_object = nil, connector_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Operation
Creates a Serverless VPC Access connector, returns an operation.
134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 134 def create_project_location_connector(parent, connector_object = nil, connector_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/connectors', ) command.request_representation = Google::Apis::VpcaccessV1::Connector::Representation command.request_object = connector_object command.response_representation = Google::Apis::VpcaccessV1::Operation::Representation command.response_class = Google::Apis::VpcaccessV1::Operation command.params['parent'] = parent unless parent.nil? command.query['connectorId'] = connector_id unless connector_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_connector(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Operation
Deletes a Serverless VPC Access connector. Returns NOT_FOUND if the resource does not exist.
168 169 170 171 172 173 174 175 176 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 168 def delete_project_location_connector(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::VpcaccessV1::Operation::Representation command.response_class = Google::Apis::VpcaccessV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_connector(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Connector
Gets a Serverless VPC Access connector. Returns NOT_FOUND if the resource does not exist.
199 200 201 202 203 204 205 206 207 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 199 def get_project_location_connector(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::VpcaccessV1::Connector::Representation command.response_class = Google::Apis::VpcaccessV1::Connector command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
303 304 305 306 307 308 309 310 311 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 303 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::VpcaccessV1::Operation::Representation command.response_class = Google::Apis::VpcaccessV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_connectors(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::ListConnectorsResponse
Lists Serverless VPC Access connectors.
233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 233 def list_project_location_connectors(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/connectors', ) command.response_representation = Google::Apis::VpcaccessV1::ListConnectorsResponse::Representation command.response_class = Google::Apis::VpcaccessV1::ListConnectorsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 348 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::VpcaccessV1::ListOperationsResponse::Representation command.response_class = Google::Apis::VpcaccessV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 96 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::VpcaccessV1::ListLocationsResponse::Representation command.response_class = Google::Apis::VpcaccessV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_connector(name, connector_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VpcaccessV1::Operation
Updates a Serverless VPC Access connector, returns an operation.
269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/google/apis/vpcaccess_v1/service.rb', line 269 def patch_project_location_connector(name, connector_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::VpcaccessV1::Connector::Representation command.request_object = connector_object command.response_representation = Google::Apis::VpcaccessV1::Operation::Representation command.response_class = Google::Apis::VpcaccessV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |